@@ -1,12 +1,12 @@
 from typing import Optional
 from functools import wraps
 import os
-import sys
 import signal
 
 from baidupcs_py import __version__
 from baidupcs_py.baidupcs import BaiduPCSApi, BaiduPCSError
 from baidupcs_py.app.account import Account, AccountManager, DEFAULT_DATA_PATH
+from baidupcs_py.common.progress_bar import _progress
 from baidupcs_py.commands.sifter import (
     IncludeSifter,
     ExcludeSifter,
@@ -41,7 +41,12 @@ DEBUG = os.getenv("DEBUG")
 
 
 def handle_signal(sign_num, frame):
-    sys.exit(1)
+    if _progress._started:
+        # Stop _progress, otherwise terminal stdout will be contaminated
+        _progress.stop()
+
+    # No use sys.exit() which only exits the main thread
+    os._exit(1)
 
 
 signal.signal(signal.SIGINT, handle_signal)
@@ -161,10 +166,13 @@ def su(ctx):
 
     am = ctx.obj.account_manager
     ls = sorted([a.user for a in am.accounts])
-    display_user_infos(*ls)
+    display_user_infos(*ls, recent_user_id=am._who)
 
     user_ids = [str(u.user_id) for u in ls] + [""]
     i = Prompt.ask("Select an user", choices=user_ids)
+    if not i:
+        return
+
     user_id = int(i)
     am.su(user_id)
     am.save()
@@ -178,18 +186,23 @@ def userlist(ctx):
 
     am = ctx.obj.account_manager
     ls = sorted([a.user for a in am.accounts])
-    display_user_infos(*ls)
+    display_user_infos(*ls, recent_user_id=am._who)
 
 
 @app.command()
 @click.option("--bduss", prompt="bduss", hide_input=True, help="用户 bduss")
-@click.option("--cookies", prompt="cookies", hide_input=True, help="用户 cookies")
+@click.option(
+    "--cookies", prompt="cookies", hide_input=True, default="", help="用户 cookies"
+)
 @click.pass_context
 @handle_error
 def useradd(ctx, bduss, cookies):
     """添加一个用户并设置为当前用户"""
 
-    cookies = dict([c.split("=", 1) for c in cookies.split("; ")])
+    if cookies:
+        cookies = dict([c.split("=", 1) for c in cookies.split("; ")])
+    else:
+        cookies = {}
     account = Account.from_bduss(bduss, cookies=cookies)
     am = ctx.obj.account_manager
     am.useradd(account.user)
@@ -205,7 +218,7 @@ def userdel(ctx):
 
     am = ctx.obj.account_manager
     ls = sorted([a.user for a in am.accounts])
-    display_user_infos(*ls)
+    display_user_infos(*ls, recent_user_id=am._who)
 
     user_ids = [str(u.user_id) for u in ls] + [""]
     i = Prompt.ask("Delete an user", choices=user_ids)
@@ -298,7 +311,7 @@ def ls(
 
     list_files(
         api,
-        *remotepaths,
+        *(remotepaths or ("/",)),
         desc=desc,
         name=name,
         time=time,
